onload = () => {
    const canvas = document.getElementById("CANVAS");
    const ctx = canvas.getContext("2d"); 

    ctx.fillStyle = 'red';
    ctx.fillRect(0, 0, ctx.canvas.width, ctx.canvas.height);

    const drawAt = (x, y) => {
        ctx.fillStyle = 'white';
        ctx.fillRect(x - 5, y - 5, 11, 11);
    };

    const getMouseCoords = (data) => {
        const { x, y } = canvas.getBoundingClientRect();

        const curX = data.clientX - x;
        const curY = data.clientY - y;

        return [curX, curY];
    };

    let buttonPressed = false;
    let prevX = null;
    let prevY = null;

    onmousemove = (data) => {
        if (!buttonPressed) { return; }

        const [curX, curY] = getMouseCoords(data);

        if (prevX === null) {
            drawAt(curX, curY);
        } else {
            const dx = curX - prevX;
            const dy = curY - prevY;

            if (dx === 0 && dy === 0) { 
                drawAt(curX, curY);
            } else if (Math.abs(dy) > Math.abs(dx)) {
                for (let i = 0; i <= Math.abs(dy); i++) {
                    const rx = prevX + dx * i / Math.abs(dy); 
                    const ry = prevY + dy * i / Math.abs(dy); 
                    drawAt(rx, ry);
                }
            } else if (Math.abs(dx) >= Math.abs(dy)) {
                for (let i = 0; i <= Math.abs(dx); i++) {
                    const rx = prevX + dx * i / Math.abs(dx); 
                    const ry = prevY + dy * i / Math.abs(dx); 
                    drawAt(rx, ry);
                }
            }
        }

        prevX = curX;
        prevY = curY;
    };

    canvas.onmousedown = (data) => {
        if (data.button != 0) { return; }
        buttonPressed = true;

        const [x, y] = getMouseCoords(data);
        drawAt(x, y);
    };

    onmouseup = (data) => {
        if (data.button != 0) { return; }
        buttonPressed = false;
        prevX = null;
        prevY = null;
    };
};


